@@ -17,7 +17,7 @@ test_that("kitchen sink parses with schema functionality", {
 
   kitchen_txt <- paste(readLines("kitchen-sink.graphql"), collapse = "\n")
 
-  json_txt <- graphql2json(kitchen_txt)
+  json_txt <- graphql2json(kitchen_txt, TRUE)
 
   result <- jsonlite::fromJSON(json_txt)
 
